.. VON-X documentation master file, created by
   sphinx-quickstart on Fri May 18 16:41:31 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to VON-X
=================================

A connector for issuing credentials to TheOrgBook as part of the Verifiable Organizations
Network (VON).

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
